@@ -1,6 +1,6 @@
 /*
     Eiciel - GNOME editor of ACL file permissions.
-    Copyright (C) 2004-2005 Roger Ferrer Ibez
+    Copyright (C) 2004-2010 Roger Ferrer Ibez
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,67 +14,64 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,  USA
 */
 #include <config.hpp>
 #include <gtkmm.h>
-#include <libgnomevfs/gnome-vfs.h>
 #include <libgnome/libgnome.h>
 #include <gettext.h>
 
-#include "eiciel_main_controler.hpp"
+#include "eiciel_main_controller.hpp"
 #include "eiciel_main_window.hpp"
 
 #ifdef ENABLE_USER_XATTR
-#include "eiciel_xattr_controler.hpp"
+#include "eiciel_xattr_controller.hpp"
 #include "eiciel_xattr_window.hpp"
 #endif
 
 class EicielContainer : public Gtk::Window
 {
 	private:
-		Gtk::VBox principal;
-		Gtk::VBox paginaACL;
-		Gtk::VBox paginaXAttr;
-		Gtk::HBox superior;
-		Gtk::HBox inferior;
-		Gtk::Button escollirFitxer;
-		Gtk::Label etiquetaFitxer;
-		Gtk::Label nomFitxer;
-		Gtk::Button sortir;
-		Gtk::Button ajuda;
-		Gtk::Button quantA;
+		Gtk::VBox _main_container;
+		Gtk::VBox _ACL_tabpage;
+		Gtk::VBox _XAttr_tabpage;
+		Gtk::HBox _top;
+		Gtk::HBox _bottom;
+		Gtk::Button _open_file;
+		Gtk::Label _file_label;
+		Gtk::Label _file_name;
+		Gtk::Button _exit_button;
+		Gtk::Button _help;
+		Gtk::Button _about;
 
-		Gtk::Notebook paginador;
+		Gtk::Notebook _notebook;
 
-		EicielWindow* widget_principal;
-		EicielMainControler* controlador_widget;
+		EicielWindow* _main_widget;
+		EicielMainController* _widget_controller;
 
 #ifdef ENABLE_USER_XATTR
-		EicielXAttrWindow* widget_xattr;
-		EicielXAttrControler* controlador_xattr;
+		EicielXAttrWindow* _xattr_widget;
+		EicielXAttrController* _xattr_controller;
 #endif
-
-		
-		void sortidaAplicacio();
-		void oberturaFitxer();
-		Glib::ustring missatgeError();
-		void mostrarQuantA();
-		void mostrarAjuda();
+		void quit_application();
+		void open_file_();
+		Glib::ustring error_message();
+		void show_about();
+		void show_help();
 
 		// FileChooser stuff
-		void chooser_file_activated(Gtk::FileChooserDialog* dialeg);
+		void chooser_file_activated(Gtk::FileChooserDialog* dialog);
 
 	public:
 		EicielContainer();
-		bool obrirFitxer(Glib::ustring nom);
+		bool open_file(Glib::ustring nom);
 };
 
 class EicielAboutBox : public Gtk::Dialog
 {
 	private:
-		Gtk::Label titol;
-		Gtk::Label autor;
+		Gtk::Label _title;
+		Gtk::Label _author;
 	public:
 		EicielAboutBox(Gtk::Window& parent);
 };
